@@ -1,14 +1,16 @@
 package App::MysqlUtils;
 
-our $DATE = '2017-06-14'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-06-15'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use Log::Any::IfLOG '$log';
 
+use IPC::System::Options qw(system);
 use Perinci::Object;
+use String::ShellQuote;
 
 our %SPEC;
 
@@ -25,20 +27,38 @@ my %args_common = (
     },
     username => {
         schema => 'str*',
+        description => <<'_',
+
+Will try to get default from `~/.my.cnf`.
+
+_
         tags => ['category:connection'],
     },
     password => {
         schema => 'str*',
+        description => <<'_',
+
+Will try to get default from `~/.my.cnf`.
+
+_
         tags => ['category:connection'],
     },
 );
 
+my %args_database0 = (
+    database => {
+        schema => 'str*',
+        req => 1,
+        pos => 0,
+        completion => \&_complete_database,
+    },
+);
+
 my %args_database = (
     database => {
         schema => 'str*',
         req => 1,
-        pos => 0,
-        completion => \&_complete_database,
+        cmdline_aliases => { db=>{} },
     },
 );
 
@@ -139,7 +159,7 @@ supply `--no-dry-run` or DRY_RUN=0.
 _
     args => {
         %args_common,
-        %args_database,
+        %args_database0,
     },
     features => {
         dry_run => {default=>1},
@@ -188,7 +208,7 @@ Examples:
 _
     args => {
         %args_common,
-        %args_database,
+        %args_database0,
         tables => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'table',
@@ -280,7 +300,7 @@ Examples:
 _
     args => {
         %args_common,
-        %args_database,
+        %args_database0,
         query => {
             schema => 'str*',
             req => 1,
@@ -364,6 +384,47 @@ sub mysql_split_sql_dump_per_table {
     [200, "OK"];
 }
 
+$SPEC{mysql_run_sql_files} = {
+    v => 1.1,
+    summary => 'Feed each .sql file to `mysql` command and '.
+        'write result to .txt file',
+    args => {
+        sql_files => {
+            schema => ['array*', of=>'filename*'],
+            req => 1,
+            pos => 0,
+            greedy => 1,
+        },
+        %args_database,
+        # XXX output_file_pattern
+        # XXX overwrite
+    },
+    deps => {
+        prog => 'mysql',
+    },
+};
+sub mysql_run_sql_files {
+    my %args = @_;
+
+    for my $sqlfile (@{ $args{sql_files} }) {
+        my $txtfile = $sqlfile;
+        $txtfile =~ s/\.sql$/.txt/i;
+        if ($sqlfile eq $txtfile) { $txtfile .= ".txt" }
+        $log->infof("Running SQL file '%s' and putting result to '%s' ...",
+                    $sqlfile, $txtfile);
+        my $cmd = join(
+            " ",
+            "mysql",
+            shell_quote($args{database}),
+            "<", shell_quote($sqlfile),
+            ">", shell_quote($txtfile),
+        );
+        system({log=>1}, $cmd);
+    }
+
+    [200, "OK"];
+}
+
 1;
 # ABSTRACT: CLI utilities related to MySQL
 
@@ -379,7 +440,7 @@ App::MysqlUtils - CLI utilities related to MySQL
 
 =head1 VERSION
 
-This document describes version 0.004 of App::MysqlUtils (from Perl distribution App-MysqlUtils), released on 2017-06-14.
+This document describes version 0.005 of App::MysqlUtils (from Perl distribution App-MysqlUtils), released on 2017-06-15.
 
 =head1 SYNOPSIS
 
@@ -418,10 +479,14 @@ Arguments ('*' denotes required arguments):
 
 =item * B<password> => I<str>
 
+Will try to get default from C<~/.my.cnf>.
+
 =item * B<port> => I<int> (default: 3306)
 
 =item * B<username> => I<str>
 
+Will try to get default from C<~/.my.cnf>.
+
 =back
 
 Special arguments:
@@ -487,6 +552,8 @@ Don't delete more than this number of tables.
 
 =item * B<password> => I<str>
 
+Will try to get default from C<~/.my.cnf>.
+
 =item * B<port> => I<int> (default: 3306)
 
 =item * B<table_pattern> => I<re>
@@ -495,6 +562,8 @@ Don't delete more than this number of tables.
 
 =item * B<username> => I<str>
 
+Will try to get default from C<~/.my.cnf>.
+
 =back
 
 Special arguments:
@@ -560,12 +629,48 @@ Add first field containing number from 1, 2, ...
 
 =item * B<password> => I<str>
 
+Will try to get default from C<~/.my.cnf>.
+
 =item * B<port> => I<int> (default: 3306)
 
 =item * B<query>* => I<str>
 
 =item * B<username> => I<str>
 
+Will try to get default from C<~/.my.cnf>.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+=head2 mysql_run_sql_files
+
+Usage:
+
+ mysql_run_sql_files(%args) -> [status, msg, result, meta]
+
+Feed each .sql file to `mysql` command and write result to .txt file.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<database>* => I<str>
+
+=item * B<sql_files>* => I<array[filename]>
+
 =back
 
 Returns an enveloped result (an array).
